@@ -5,9 +5,12 @@ from pathlib import Path
 import sys
 
 import mincepy
+import pytest
 
 import minkipy
 
+# pylint: disable=unused-argument
+
 
 def test_load_script():
     script = """\
@@ -112,3 +115,49 @@ def test_task_stds(tmp_path, test_project):
         loaded, loaded2 = mincepy.load(task_id, task2_id)
         assert 'Hello stdout!' in loaded.stdout.read_text()
         assert 'Hello stderr!' in loaded2.stderr.read_text()
+
+
+def exceptional_task(msg):
+    raise RuntimeError(msg)
+
+
+def test_task_exception(tmp_path, test_project):
+    msg = "all was going well except then the exceptional task excepted"
+    task = minkipy.task(exceptional_task, args=(msg,))
+
+    with pytest.raises(RuntimeError):
+        task.run()
+
+    assert msg in task.log_file.read_text()
+
+
+def test_task_resubmit(tmp_path, test_project, test_queue):
+    task = minkipy.task(exceptional_task, args=[
+        'Arrrgg...',
+    ])
+    test_queue.submit(task)
+
+    with test_queue.next_task(timeout=2.) as incoming:
+        incoming.run()
+
+    assert task.queue == test_queue.name
+    assert task.state == minkipy.FAILED
+    assert 'Arrrgg...' in task.error
+
+    task.resubmit()
+    assert task.state == minkipy.QUEUED
+    assert task in test_queue
+    assert not task.error
+
+    with test_queue.next_task(timeout=2.) as incoming:
+        incoming.run()
+
+    # Now try resubmitting on different queue (priority)
+    priority = minkipy.queue('priority')
+    task.resubmit(queue='priority')
+    assert task.state == minkipy.QUEUED
+    assert task.queue == 'priority'
+    assert task in priority
+    assert not task.error
+    with minkipy.queue('priority').next_task(timeout=2.) as incoming:
+        incoming.run()
